@@ -26,7 +26,7 @@
 /*
  * Defines
  */
-#define VERSION			"4.2"
+#define VERSION			"4.3"
 
 #define MAX_STRING      	2048
 #define OUTBUF_LENGTH		2048
@@ -87,6 +87,7 @@
 #define ANSI_UNDERLINE		4
 #define ANSI_BLINK		5
 #define ANSI_REVERSE		7
+#define ANSI_BOLD_OFF		22
 #define ANSI_UNDERLINE_OFF	24
 #define ANSI_BLINK_OFF		25
 #define ANSI_REVERSE_OFF	27
@@ -98,6 +99,7 @@
 #define ANSI_FG_MAGENTA		35
 #define ANSI_FG_CYAN		36
 #define ANSI_FG_WHITE		37
+#define ANSI_FG_DEFAULT		39
 
 typedef enum color_types {
     /* 0 is reserved */
