@@ -620,6 +620,9 @@ int check_esc(char *pBuf, int *attrib)
 			    case ANSI_BLINK:
 			        *attrib |= A_BLINK;
 				break;
+			    case ANSI_BOLD_OFF:
+			        *attrib &= ~A_BOLD;
+				break;
 			    case ANSI_REVERSE_OFF:
 			        *attrib &= ~A_REVERSE;
 				break;
@@ -629,6 +632,9 @@ int check_esc(char *pBuf, int *attrib)
 			    case ANSI_BLINK_OFF:
 			        *attrib &= ~A_BLINK;
 				break;
+			    case ANSI_FG_DEFAULT:
+			        *attrib &= ~A_COLOR;
+				break;
 			    case ANSI_FG_BLACK:
 			    case ANSI_FG_RED:
 			    case ANSI_FG_GREEN:
